The next group of projects are all based around the game Minecraft, with the goal of allowing you to create and modify your own Minecraft controller. If you're not familiar with it, Minecraft is a video game where you construct and deconstruct various 3D worlds. Unlike many video games where there is a specific goal (complete a mission, solve a puzzle, etc), in Minecraft the goal is generally just to explore and have fun.

In this particular project, we will focus on simply getting familiar with the process of starting and stopping Minecraft on the CREATOR Kit.

This project won't use the CREATOR Kit hardware, so no hardware setup required.

The Raspberry Pi comes preloaded with a simplified version of Minecraft tailored to the Raspberry Pi. It runs in creative mode only, which means you can freely create and edit the world as you want (plus you can fly!). In addition, it has a custom API for editing the world and editing the functionality of your Minecraft character. Both single and multiplayer modes are supported.

With the API you can create programs that interact with both your electronics AND the Minecraft world. This will be very important as we develop the next group of projects geared towards creating and build your own Minecraft controller, and then giving your controller whatever functionality you wish.

## Running Minecraft

In order to do your custom Minecraft programming with the Ready Set STEM kit, you'll typically do the following steps (which we'll discuss in more detail below):

1. Exit this RDE to get to the Raspberry Pi desktop

2. Start Minecraft

3. Minimize Minecraft

4. Return to the RDE

5. Write and run your code from the RDE

IMPORTANT NOTE: EXITING MINECRAFT

Before you read any further, we have an important note that you're going to want to keep in mind as you run Minecraft on the Raspberry Pi. Every time you start Minecraft, you're eventually going to want to exit the game to get back to the RDE, but the game will take over the screen, the keyboard and the mouse while you're playing.

In order to get control of your keyboard/mouse back from the Minecraft game you need to press the "TAB" button on your keyboard.

This will then allow you to click on the menu items (minimize, exit) in the Minecraft window.

### Exit this RDE to get to the Raspberry Pi desktop

To get to the Raspberry Pi Desktop, you need to type CTRL-ALT-D (press the CTRL key, the ALT key and the letter D on the keyboard all at the same time). This will bring you to the "desktop," which looks like this:

### Start Minecraft

Once on the Raspberry Pi Desktop, you open Minecraft by clicking on "Menu" in the upper left corner of the desktop, clicking on "Games" and then clicking on "Minecraft" — like this:

To begin using Minecraft, first click the "Start Game" button from the main window:

Then click "Create new" to create a new world and start playing:

You're now playing Minecraft! The keyboard and mouse will control your player, named "Steve."

### Minimize Minecraft

While you can continue to play Minecraft without any modifications, we think you'll have a lot more fun (and learn a lot more!) by using the Ready Set STEM kit to program and modify the Minecraft world. To do that, you'll write programs using the Ready Set STEM RDE — just like we've been doing in all our previous projects. In order to get back to the RDE to start writing your programs, you'll first need to minimize the Minecraft window.

To do this, you'll need to:

- Press the "TAB" key on the keyboard. This will free the mouse up so that it can be used to control the mouse cursor.

- Then, click the minimize button in the upper right corner of the window.

### Return to the RDE

Once the Minecraft window is minimized, to return to the RDE, you'll click on the minimized Ready Set STEM window icon at the top of the screen. You're now back in the RDE.

### Write and run your code from the RDE

Now that Minecraft is running in the background in a minimize window, it's time to start writing your custom Minecraft code. Let's jump into our first Minecraft project to get an idea of how that will work...